@@ -24,8 +24,8 @@ OC.L10N.register(
     "Next week" : "Järgmine nädal",
     "Next year" : "Järgmine aasta",
     "Next month" : "Järgmine kuu",
-    "Event" : "Sündmus",
     "Create new event" : "Lisa uus sündmus",
+    "Event" : "Sündmus",
     "Today" : "Täna",
     "Day" : "Päev",
     "Week" : "Nädal",
@@ -42,12 +42,12 @@ OC.L10N.register(
     "Add new" : "Lisa uus",
     "New calendar" : "Uus kalender",
     "Export" : "Ekspordi",
+    "Empty trash bin" : "Tühjenda prügikast",
     "Trash bin" : "Prügikast",
     "Name" : "Nimi",
     "Deleted" : "Kustutatud",
     "Restore" : "Taasta",
     "Delete permanently" : "Kustuta jäädavalt",
-    "Empty trash bin" : "Tühjenda prügikast",
     "Deck" : "Deck",
     "Hidden" : "Peidetud",
     "Internal link" : "Sisemine link",
@@ -75,8 +75,8 @@ OC.L10N.register(
     "List view" : "Nimekirjavaade",
     "Actions" : "Tegevused",
     "Create event" : "Lisa sündmus",
-    "Show week numbers" : "Näita nädalanumberid",
     "Calendar settings" : "Kalendri seaded",
+    "Show week numbers" : "Näita nädalanumberid",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minutit"],
     "0 minutes" : "0 minutit",
     "_{duration} hour_::_{duration} hours_" : ["{duration} tund","{duration} tundi"],
@@ -84,6 +84,7 @@ OC.L10N.register(
     "_{duration} week_::_{duration} weeks_" : ["{duration} nädal","{duration} nädalat"],
     "_{duration} month_::_{duration} months_" : ["{duration} kuu","{duration} kuud"],
     "_{duration} year_::_{duration} years_" : ["{duration} aasta","{duration} aastat"],
+    "Update" : "Uuenda",
     "Location" : "Asukoht",
     "Description" : "Kirjeldus",
     "Visibility" : "Nähtavus",
@@ -97,26 +98,25 @@ OC.L10N.register(
     "Friday" : "Reede",
     "Saturday" : "Laupäev",
     "Sunday" : "Pühapäev",
-    "Update" : "Uuenda",
     "Your email address" : "Sinu e-posti aadress",
     "Notification" : "Teavitus",
     "Email" : "E-post",
     "On date" : "Kuupäeval",
-    "_second_::_seconds_" : ["sekund","sekundit"],
-    "_minute_::_minutes_" : ["minut","minutit"],
-    "_hour_::_hours_" : ["tund","tundi"],
-    "_day_::_days_" : ["päev","päeva"],
-    "_week_::_weeks_" : ["nädal","nädalat"],
+    "seconds" : "sekundit",
+    "minutes" : "minutit",
+    "hours" : "tundi",
+    "days" : "päeva",
+    "weeks" : "nädalat",
+    "Choose a file to add as attachment" : "Vali fail, mida manustada",
+    "Attachment {name} already exist!" : "Manus {name} on juba olemas!",
     "No attachments" : "Manuseid pole",
     "Add from Files" : "Lisa failidest",
     "Upload from device" : "Laadi üles seadmest",
     "Delete file" : "Kustuta fail",
-    "Choose a file to add as attachment" : "Vali fail, mida manustada",
-    "Attachment {name} already exist!" : "Manus {name} on juba olemas!",
     "_{count} attachment_::_{count} attachments_" : ["{count} manus","{count} manust"],
-    "Done" : "Valmis",
     "Out of office" : "Kontorist väljas",
     "Unknown" : "Teadmata",
+    "Done" : "Valmis",
     "Accept" : "Nõustu",
     "Decline" : "Keeldu",
     "Tentative" : "Esialgne",
@@ -128,6 +128,8 @@ OC.L10N.register(
     "Repeat" : "Korda",
     "never" : "mitte kunagi",
     "after" : "pärast",
+    "_day_::_days_" : ["päev","päeva"],
+    "_week_::_weeks_" : ["nädal","nädalat"],
     "_month_::_months_" : ["kuu","kuud"],
     "Does not repeat" : "Ei kordu",
     "Global" : "Üldine",
@@ -145,6 +147,7 @@ OC.L10N.register(
     "Weekly" : "Iga nädal",
     "Monthly" : "Igakuine",
     "Yearly" : "Igaastane",
+    "second" : "teine",
     "Other" : "Muu",
     "When shared show full event" : "Kui on jagatud, siis näita kogu sündmust",
     "When shared show only busy" : "Kui on jagatud, siis näita ainult, kas on hõivatud",
